==> qtjambi-concurrent-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiConcurrent/QtConcurrent_MedianDouble_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtConcurrent/qtconcurrentmedian.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QtConcurrent_MedianDouble(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QtConcurrent::MedianDouble")
    QtConcurrent::MedianDouble *_ptr = reinterpret_cast<QtConcurrent::MedianDouble *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new MedianDouble()
void __qt_construct_QtConcurrent_MedianDouble_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct MedianDouble()")
    Q_UNUSED(__java_arguments)
    QtConcurrent::MedianDouble *__qt_this = new(__qtjambi_ptr) QtConcurrent::MedianDouble();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QtConcurrent::MedianDouble
void __qt_destruct_QtConcurrent_MedianDouble(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtConcurrent::MedianDouble")
    reinterpret_cast<QtConcurrent::MedianDouble*>(ptr)->~MedianDouble();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QtConcurrent::MedianDouble::MedianDouble()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_initialize_1native__Lio_qt_concurrent_QtConcurrent_00024MedianDouble_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtConcurrent::MedianDouble::MedianDouble()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtConcurrent_MedianDouble_0, sizeof(QtConcurrent::MedianDouble), typeid(QtConcurrent::MedianDouble), false, &deleter_QtConcurrent_MedianDouble, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtConcurrent::MedianDouble::addValue(double)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_addValue_1native_1double__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble value0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::addValue(double)", __qt_this)
        __qt_this->addValue(static_cast<double>(value0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtConcurrent::MedianDouble::isMedianValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_isMedianValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::isMedianValid()const", __qt_this)
        __java_return_value = __qt_this->isMedianValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtConcurrent::MedianDouble::median()
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_median_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::median()", __qt_this)
        __java_return_value = __qt_this->median();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtConcurrent::MedianDouble::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QtConcurrent_MedianDouble(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QtConcurrent::MedianDouble>("QtConcurrent::MedianDouble", "io/qt/concurrent/QtConcurrent$MedianDouble");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QtConcurrent_MedianDouble, {
        ConstructorInfo(&__qt_construct_QtConcurrent_MedianDouble_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QtConcurrent_MedianDouble);
    registerMetaType<QtConcurrent::MedianDouble>("QtConcurrent::MedianDouble");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-concurrent-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiConcurrent/QtConcurrent_MedianDouble_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtConcurrent/qtconcurrentmedian.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QtConcurrent_MedianDouble(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QtConcurrent::MedianDouble")
    QtConcurrent::MedianDouble *_ptr = reinterpret_cast<QtConcurrent::MedianDouble *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new MedianDouble()
void __qt_construct_QtConcurrent_MedianDouble(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct MedianDouble()")
    Q_UNUSED(__java_arguments)
    QtConcurrent::MedianDouble *__qt_this = new(__qtjambi_ptr) QtConcurrent::MedianDouble();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QtConcurrent::MedianDouble::MedianDouble()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_initialize_1native__Lio_qt_concurrent_QtConcurrent_00024MedianDouble_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtConcurrent::MedianDouble::MedianDouble()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtConcurrent_MedianDouble, sizeof(QtConcurrent::MedianDouble), typeid(QtConcurrent::MedianDouble), false, &deleter_QtConcurrent_MedianDouble, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new MedianDouble(QtConcurrent::MedianDouble)
void __qt_construct_QtConcurrent_MedianDouble_cref_QtConcurrent_MedianDouble(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct MedianDouble(QtConcurrent::MedianDouble)")
    jobject other0 = __java_arguments[0].l;
    const QtConcurrent::MedianDouble& __qt_other0 = qtjambi_cast<const QtConcurrent::MedianDouble& >(__jni_env, other0);
    QtConcurrent::MedianDouble *__qt_this = new(__qtjambi_ptr) QtConcurrent::MedianDouble(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QtConcurrent::MedianDouble::MedianDouble(QtConcurrent::MedianDouble)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_initialize_1native__Lio_qt_concurrent_QtConcurrent_00024MedianDouble_2Lio_qt_concurrent_QtConcurrent_00024MedianDouble_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtConcurrent::MedianDouble::MedianDouble(QtConcurrent::MedianDouble)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtConcurrent_MedianDouble_cref_QtConcurrent_MedianDouble, sizeof(QtConcurrent::MedianDouble), typeid(QtConcurrent::MedianDouble), false, &deleter_QtConcurrent_MedianDouble, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QtConcurrent::MedianDouble
void __qt_destruct_QtConcurrent_MedianDouble(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtConcurrent::MedianDouble")
    reinterpret_cast<QtConcurrent::MedianDouble*>(ptr)->~MedianDouble();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QtConcurrent::MedianDouble::addValue(double)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_addValue_1native_1double__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble value0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::addValue(double)", __qt_this)
        __qt_this->addValue(static_cast<double>(value0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtConcurrent::MedianDouble::isMedianValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_isMedianValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::isMedianValid()const", __qt_this)
        __java_return_value = __qt_this->isMedianValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtConcurrent::MedianDouble::median()
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_median_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::median()", __qt_this)
        __java_return_value = __qt_this->median();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtConcurrent::MedianDouble::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtConcurrent::MedianDouble::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_concurrent_QtConcurrent_00024MedianDouble_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QtConcurrent::MedianDouble *__qt_this = QtJambiAPI::objectFromNativeId<QtConcurrent::MedianDouble>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QtConcurrent_MedianDouble(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QtConcurrent::MedianDouble>("QtConcurrent::MedianDouble", "io/qt/concurrent/QtConcurrent$MedianDouble");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QtConcurrent_MedianDouble, {
        ConstructorInfo(&__qt_construct_QtConcurrent_MedianDouble, nullptr)
       ,ConstructorInfo(&__qt_construct_QtConcurrent_MedianDouble_cref_QtConcurrent_MedianDouble, "Lio/qt/concurrent/QtConcurrent$MedianDouble;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QtConcurrent_MedianDouble);
    registerMetaType<QtConcurrent::MedianDouble>("QtConcurrent::MedianDouble");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
